Functions
- extract_
github_ refs - Extract GitHub issue/PR references from text. Returns a list of (repo_name, number) tuples.
- validate_
repo - Validate
org/repoformat. Returns an error string, or empty string if valid.
org/repo format. Returns an error string, or empty string if valid.