pub struct JsonGrepMatch {
pub field: String,
pub lines: Vec<usize>,
pub context_start: usize,
pub context_end: usize,
pub content: String,
}Expand description
One grep match within a JSON structure.
Fields
field: StringDotted JSON path to the field where the match occurred.
lines: Vec<usize>1-indexed line numbers of matching lines within the field’s value.
context_start: usizecontext_end: usizecontent: StringTrait Implementations
Sourceimpl Clone for JsonGrepMatch
impl Clone for JsonGrepMatch
Sourcefn clone(&self) -> JsonGrepMatch
fn clone(&self) -> JsonGrepMatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for JsonGrepMatch
impl RefUnwindSafe for JsonGrepMatch
impl Send for JsonGrepMatch
impl Sync for JsonGrepMatch
impl Unpin for JsonGrepMatch
impl UnsafeUnpin for JsonGrepMatch
impl UnwindSafe for JsonGrepMatch