pub fn select<'a>(
profiles: &'a [UserProfile],
sel: &Selection,
) -> Vec<&'a UserProfile>Expand description
Filter → rank → take. The selection function, reused for the overview view and the fan-out gate (expand only these top-K).
pub fn select<'a>(
profiles: &'a [UserProfile],
sel: &Selection,
) -> Vec<&'a UserProfile>Filter → rank → take. The selection function, reused for the overview view and the fan-out gate (expand only these top-K).