pub fn parse_skill(
content: &str,
path: &Path,
) -> Result<(SkillFrontmatter, String), SkillError>Expand description
Parse a SKILL.md content blob into its frontmatter struct and markdown body.
pub fn parse_skill(
content: &str,
path: &Path,
) -> Result<(SkillFrontmatter, String), SkillError>Parse a SKILL.md content blob into its frontmatter struct and markdown body.