pub struct ListDirOpts<'a> {
pub depth: Option<usize>,
pub glob: Option<&'a str>,
pub dirs_only: bool,
pub relative_to: Option<&'a str>,
pub respect_gitignore: bool,
pub skip_dirs: Option<&'a [String]>,
pub include_size: bool,
pub annotate: Option<&'a AnnotateFn>,
}Expand description
Optional knobs for list_dir.
Fields
depth: Option<usize>Recursion depth (default 1 = flat ls; 2+ = nested tree).
glob: Option<&'a str>dirs_only: boolrelative_to: Option<&'a str>respect_gitignore: boolRespect .gitignore / .git/info/exclude rules (default true).
skip_dirs: Option<&'a [String]>Custom directory names to skip. When None, a built-in list
(.git, node_modules, target, …) is used.
include_size: boolannotate: Option<&'a AnnotateFn>Per-entry annotation callback. Receives the entry’s path
relative to relative_to (or the root if unset) and returns
Some(annotation) to append after the entry, or None to skip.
Used by the Python wrapper to bridge a Python callable.